/* GCC */

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <cmath>
#include <utility>
#include <stdint.h>
#include <inttypes.h>
#include <cstring>
#include <climits>
#include <stack>
using namespace std;

const int Nmax = 530;
const int Fmax = 260;

short m[Nmax][Nmax] = {};
int dt[4][2] = {{1, 0}, {0, 1}, {-1, 0}, {0, -1}};

struct Figure
{
    int w, h, x0, y0, id, n;
};

Figure figs[Fmax] = {};

int mini, minj, maxi, maxj, nk;

void get_fig(short t[Nmax][Nmax], Figure f)
{
    for (int i = 0; i < f.h; ++i) {
        for (int j = 0; j < f.w; ++j) {
            if (m[f.x0+i][f.y0+j] == f.id)
                t[i][j] = 1;
        }
    }
}

bool cmp(short t1[][Nmax], short t2[][Nmax])
{
    return memcmp(t1, t2, Nmax*Nmax*2) == 0;
}

void horiz_symm(short t[][Nmax], Figure f)
{
    for (int i = 0; i < f.h; ++i) {
        reverse(t[i], t[i]+f.w);
    }
}

void vert_symm(short t[][Nmax], Figure f)
{
    for (int i = 0; i < f.w; ++i) {
        for (int j = 0, k = f.h-1; j < k; ++j, --k) {
            swap(t[j][i], t[k][i]);
        }
    }
}

void transp(short t[][Nmax], Figure& f)
{
    static short t2[Nmax][Nmax];
    memset(t2, 0, Nmax*Nmax*2);
    
    for (int i = 0; i < f.h; ++i) {
        for (int j = 0; j < f.w; ++j) {
            t2[j][i] = t[i][j];
        }
    }
    swap(f.h, f.w);
    memcpy(t, t2, Nmax*Nmax*2);
}

bool check(short t1[][Nmax], Figure f1, short t2[][Nmax], Figure f2)
{
    if (cmp(t1, t2))
        return true;
    horiz_symm(t1, f1);
    if (cmp(t1, t2))
        return true;
    vert_symm(t1, f1);
    if (cmp(t1, t2))
        return true;
    horiz_symm(t1, f1);
    if (cmp(t1, t2))
        return true;
    vert_symm(t1, f1);
    
    return false;
}

void dfs(int i, int j, int k)
{
    mini = minj = INT_MAX;
    maxi=maxj=INT_MIN;
    nk = 0;
    stack<pair<int, int> > s;
    s.push(make_pair(i, j));
    m[i][j] = k;

    while (!s.empty())
    {
        int x = s.top().first;
        int y = s.top().second;
        s.pop();

        m[x][y] = k;
        ++nk;

        if (x > maxi)
            maxi = x;
        if (x < mini)
            mini = x;
        if (y > maxj)
            maxj = y;
        if (y < minj)
            minj = y;

        for (int ii = 0; ii < 4; ++ii)
        {
            int dx = x + dt[ii][0];
            int dy = y + dt[ii][1];
            if (0 > dx || Nmax <= dx || 0 > dy || Nmax <= dy)
                continue;
            if (m[dx][dy] == -1)
            {
                s.push(make_pair(dx, dy));
                //m[dx][dy] = k;
            }
        }
    }
}

int main()
{
    freopen("test.in", "r", stdin);
    freopen("test.out", "w", stdout);
    int n;
    scanf("%d", &n);
    getchar();

    char line[900];

    for (int i = 0; i < n; ++i)
    {
        fgets(line, 900, stdin);
        for (int j = 0; j < n; ++j)
        {
            if (line[j] != ' ')
                m[i][j] = -1;
        }
    }
    int k = 1;

    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < n; ++j)
        {
            if (m[i][j] == -1)
            {
                dfs(i, j, k);
                figs[k].x0 = mini;
                figs[k].y0 = minj;
                figs[k].h = maxi - mini+1;
                figs[k].w = maxj - minj+1;
                figs[k].id = k;
                figs[k].n = nk;
                ++k;
            }
        }
    }
    
    int uniq = k;
    
    for (int i = 1; i < uniq; ++i) {
        for (int j = i+1; j < uniq; ++j) {
            static short t1[Nmax][Nmax], t2[Nmax][Nmax];
            
            Figure f1 = figs[i], f2 = figs[j];
            if (f1.n != f2.n || min(f1.h, f1.w) != min(f2.h, f2.w) || max(f1.h, f1.w) != max(f2.h, f2.w))
                continue;
            
            memset(t1, 0, Nmax*Nmax*2);
            memset(t2, 0, Nmax*Nmax*2);
            
            get_fig(t1, f1);
            get_fig(t2, f2);
            
            if (check(t1, f1, t2, f2)) {
                swap(figs[j], figs[uniq-1]);
                --j;
                --uniq;
                continue;
            }
            transp(t1, f1);
            if (check(t1, f1, t2, f2)) {
                swap(figs[j], figs[uniq-1]);
                --j;
                --uniq;
                continue;
            }
        }
    }
    
    printf("%d %d\n", k-1, uniq-1);
    
    return 0;
}
